function [V] = OrientationPoints(S)
%
% Функция OrientationPoints по матрице S определяет ориентационные точки.
% Ориентационная точка - это вершина пересечения множества решений 
% с каким-нибудь ортантом.
% Из каждой вершины выходит хоть один граничный интервал, 
% поэтому все вершины перечислены в первых двух столбцах матрицы S 
% (в первом столбце - абсцисса, во втором - ордината вершины).
% В отличии от других начал граничных интервалов, вершины
% имеют значения из R (в координатах вершин нет -Inf, Inf, NaN).

   V=S(:,1:2); % матрица из начал участков

   xbf=isfinite(V(:,1));
   ybf=isfinite(V(:,2));
   bf=~min(xbf,ybf); % граничные интервалы неравенств S(bf,5) 
                     % имеют начало в бесконечности

   V(bf,:)=[]; % матрица ориентационных точек с повторами
   V=NonRepeatRows(V);

end